import pages
import unittest
import selenium.webdriver
from holmium.core import PageElement, Locators
class TextSearchTest(unittest.TestCase):
    def setUp(self):
        self.driver = selenium.webdriver.Firefox()
        self.page = pages.GoogleMain(self.driver, "http://www.google.com")

    def test_text_search(self):
        self.page.search("selenium") # execute the page object method search
        assert len(self.page.search_results) > 0

    def test_text_search_first_result(self):
        self.page.search("selenium") # execute the page object method search
        # extract the a.l element of the first search result
        first_text_result_link = PageElement(Locators.CSS_SELECTOR, "a.l", self.page.search_results[0]).extract()
        assert first_text_result_link.text == "Selenium - Web Browser Automation"

    def tearDown(self):
        self.driver.quit()



from holmium.core import PageObject, PageElement, PageElements, Locators, PageElementMap


class WikiPedia(PageObject):
    languages = PageElementMap( Locators.CLASS_NAME, "central-featured-lang"
                                    , key = lambda el:el.get_attribute("lang")
                                    , value = lambda el: el.find_element_by_tag_name("a"))
    search_box = PageElement( Locators.CSS_SELECTOR, "input#searchInput" )
    article_title = PageElement( Locators.CSS_SELECTOR, "h1#firstHeading span" )
    search_results = PageElementMap( Locators.CSS_SELECTOR, "div.mw-search-result-heading>a")
    def search(self,  query ):
        self.search_box.clear()
        self.search_box.send_keys( query )
        self.search_box.submit()





from logger import log
from holmium.core.testcase import HolmiumTestCase
from holmium.core.pageobject import Locators, PageObject, PageElement, PageElements
from holmium.core.pageobject import PageElementMap
from holmium.core.decorators import repeat



"""
setup.py for holmium.core


"""
__author__ = "Ali-Akber Saifee"
__email__ = "ali@mig33global.com"
__copyright__ = "Copyright 2013, ProjectGoth"

from setuptools import setup
import codecs
import holmium.version
setup(
    name='holmium.core',
    author = __author__,
    author_email = __email__,
    license = "MIT",
    url="https://holmiumcore.readthedocs.org/en/latest/",
    zip_safe = False,
    version=holmium.version.__version__,
    include_package_data = True,
    description='selenium page objects and other utilities for test creation',
    long_description=codecs.open('README.rst').read(),
    packages = ['holmium','holmium.core'],
)

